"use client";
import React, { useEffect, useState, useRef } from "react";
import { Stepper, Step, StepLabel } from "@/components/ui/steps";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { useTranslations } from "next-intl";
import toast, { Toaster } from "react-hot-toast";
import {
  postApiData,
  postWithToken,
  postApiFormDataToken,
  postApiFormDataTokenWithProgress,
} from "@/Helper/common";
import { CircularProgress } from "@/components/ui/progress";
import { FileUploader } from "react-drag-drop-files";
import Select from 'react-dropdown-select';

import { cn } from "@/lib/utils";
import { useMediaQuery } from "@/hooks/use-media-query";
import { getWithToken } from "@/Helper/common";
import { ifStatement } from "@babel/types";
import { useRouter } from "next/navigation";
import { useLanguage } from '../../../../../../context/LanguageContext';
import { Divider } from "@mantine/core";
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group";


const BasicWizard = () => {
  // otp form
  const { locale, changeLanguage, messages } = useLanguage();

  const fileTypes = ["JPG", "PNG", "GIF", 'jpg', 'jpeg', 'png'];
  const lang = useTranslations("Kyc_Update");
  const route = useRouter();
  const [location, setLocation] = useState();
  const [countdown, setCountdown] = useState(0);
  const [isCounting, setIsCounting] = useState(false);
  const [onlineVerifyBank, setOnlineVerifyBank] = useState('Pending');
  const [stateData, setStateData] = useState([]);
  const [cityData, setCityData] = useState([]);
  const [cityBusinessData, setCityBusinessData] = useState([]);
  const [selected, setSelected] = useState('Yes');
  const [registerAsARetailer, setRegisterAsARetailer] = useState(false);


  useEffect(() => {
    if ("geolocation" in navigator) {
      navigator.geolocation.getCurrentPosition(({ coords }) => {
        const { latitude, longitude } = coords;
        const formattedLatitude = parseFloat(latitude).toFixed(4);
        const formattedLongitude = parseFloat(longitude).toFixed(4);

        setLocation({
          latitude: formattedLatitude,
          longitude: formattedLongitude,
        });
        console.log({
          latitude: formattedLatitude,
          longitude: formattedLongitude,
        });
      });
    }
  }, []);

  useEffect(() => {
    let timer;
    if (isCounting && countdown > 0) {
      timer = setInterval(() => {
        setCountdown(prevCountdown => prevCountdown - 1);
      }, 1000);
    } else if (countdown === 0) {
      setIsCounting(false);
    }
    return () => clearInterval(timer);
  }, [isCounting, countdown]);




  const [activeStep, setActiveStep] = React.useState(0);
  const [resultData, setKycDetailsData] = useState([]);
  // first form
  const [fname, setFname] = useState("");
  const [mname, setMname] = useState("");
  const [lname, setLname] = useState("");
  const [email, setEmail] = useState("");
  const [date, setDate] = useState("");
  const [address, setAddress] = useState("");
  const [city, setCity] = useState("");
  const [state, setState] = useState("");
  const [pincode, setPincode] = useState("");

  // sencod form

  // Individual state variables for business-related fields
  const [businessType, setBusinessType] = useState("");
  const [businessName, setBusinessName] = useState("");
  const [businessMobile, setBusinessMobile] = useState("");
  const [businessAdd, setBusinessAdd] = useState("");
  const [businessCity, setBusinessCity] = useState("");
  const [businessState, setBusinessState] = useState("");
  const [businessPincode, setBusinessPincode] = useState("");

  const [showOTP, setShowOTP] = useState(false);
  const [loading, setLoading] = useState(false);


  const [gst, setGstQuestion] = useState("");
  const [showGSTInput, setShowGSTInput] = useState(false);
  const [gstNumber, setGSTNumber] = useState("");
  const [designationType, setDesignationType] = useState("");
  const [user_id, setUserId] = useState(0);
  const [bankList, setBankList] = useState([]);
  const [defaultValuesBCity, setDefaultValuesBCity] = useState([]);
  const [defaultValuesBState, setDefaultValuesBState] = useState([]);


  useEffect(() => {
    fetchKycData();
    fetchAepsBankData();
  }, []);

  var apiCall = true;

  const fetchKycData = async () => {
    try {

      if (apiCall) {

        apiCall = false;

        const apiResData = await getWithToken("get-kyc-details");
        // console.log(apiResData);
        if (apiResData.error === false) {
          setKycDetailsData(apiResData.data);
          if (apiResData.data) {
            setBusinessName(apiResData?.data.business_name);
            setBusinessMobile(apiResData?.data.business_mobile);
            setBusinessAdd(apiResData?.data.business_address);
            setBusinessPincode(apiResData?.data.business_pincode);
            setGSTNumber(apiResData?.data.gst_number);
            setGstQuestion(apiResData?.data.gst);
            setDefaultValuesBCity([{ value: apiResData?.data?.business_city, label: apiResData?.data?.business_city }]);
            setDefaultValuesBState([{ value: apiResData?.data?.business_state, label: apiResData?.data?.business_state }]);
            setDesignationType(apiResData?.userData.designation_id);
            setUserId(apiResData?.userData?.id);
          }
        }

        const getState = await getWithToken("web/getStateData");
        // console.log(apiResData);
        if (getState.error === false) {
          setStateData(getState.result);

        }
      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };


  const fetchAepsBankData = async () => {
    try {

      const apiResData = await getWithToken(`beneficiary/get-aeps-bank-data`);
      // console.log(apiResData);
      if (apiResData.error === false) {

        setBankList(apiResData?.result);
      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };

  // validation form 1
  const [errors, setErrors] = useState({

    businessName: "",
    businessMobile: "",
    businessAdd: "",
    businessCity: "",
    businessState: "",
    businessPincode: "",
  });

  const [businessFormData, setBusinessFormData] = useState({
    businessName: "",
    businessMobile: "",
    businessAdd: "",
    businessCity: "",
    businessState: "",
    businessPincode: "",
  });


  const validateBusiness = () => {
    let isValid = true;
    const newErrors = { ...errors };

    if (!businessName.trim()) {
      newErrors.businessName = lang("businessName");
      isValid = false;
    } else {
      newErrors.businessName = "";
    }
    if (!businessMobile.trim()) {
      newErrors.businessMobile = lang("businessMobile");
      isValid = false;
    } else {
      newErrors.businessMobile = "";
    }

    if (!businessAdd.trim()) {
      newErrors.businessAdd = lang("businessAdd");
      isValid = false;
    } else {
      newErrors.businessAdd = "";
    }

    if (!businessCity.trim()) {
      newErrors.businessCity = lang("businessCity");
      isValid = false;
    } else {
      newErrors.businessCity = "";
    }

    if (!businessState.trim()) {
      newErrors.businessState = lang("businessState");
      isValid = false;
    } else {
      newErrors.businessState = "";
    }

    if (!businessPincode.trim()) {
      newErrors.businessPincode = lang("businessPincode");
      isValid = false;
    } else if (!/^\d+$/.test(businessPincode.trim())) {
      newErrors.pincode = "Pincode must be numeric *";
      isValid = false;
    } else {
      newErrors.businessPincode = "";
    }

    if (showGSTInput) {
      const gstNumberPattern =
        /^[0-9]{2}[A-Z]{5}[0-9]{4}[A-Z]{1}[1-9A-Z]{1}Z[0-9A-Z]{1}$/;

      if (!gstNumber.trim()) {
        newErrors.gstNumber = "GST Number is required *";
        isValid = false;
      } else if (!gstNumberPattern.test(gstNumber.trim())) {
        newErrors.gstNumber = "Invalid GST Number format *";
        isValid = false;
      } else {
        newErrors.gstNumber = "";
      }
    }

    setErrors(newErrors);
    return isValid;
  };

  const isTablet = useMediaQuery("(max-width: 1024px)");

  const handleSelectChange = (event) => {
    const selectedValue = event.target.value;
    setGstQuestion(selectedValue);
    setShowGSTInput(selectedValue === "Yes");
    setGSTNumber("");
  };


  const [showOTPForm, setShowOTPForm] = useState(false);
  const [finalSubmitLoading, setFinalSubmitLoading] = useState(false);
  const [showManualMessage, setShowManualMessage] = useState('');
  const [showUploadDocumentForm, setShowUploadDocumentForm] = useState(false);
  // const [OTP, setOTP] = useState('');

  const [progressKycSubmit, setProgressKycSubmit] = useState(0);


  const handleChangePincode = (e) => {
    const { value } = e.target;
    if (/^\d*$/.test(value)) {
      setPincode(value);
    }
  };
  const handleChangeBusinessPincode = (e) => {
    const { value } = e.target;
    if (/^\d*$/.test(value)) {
      setBusinessPincode(value);
    }
  };

  const handleChangeBusinessMobile = (e) => {
    const { value } = e.target;
    if (/^\d*$/.test(value)) {
      setBusinessMobile(value.split(" ").join(""));
    }
  };


  const handleKycSubmit = async () => {

    setProgressKycSubmit(0);
    const onProgressKycSubmit = (progress) => {
      setProgressKycSubmit(progress); // Update progress in state
    };

    if (!validateBusiness()) {

      return false;

    } else {


      setFinalSubmitLoading(true);

      const apiData = new FormData();

      apiData.append("business_name", businessName);
      apiData.append("business_mobile", businessMobile);
      apiData.append("gst", gst);
      apiData.append("gst_number", gstNumber);
      apiData.append("business_address", businessAdd);
      apiData.append("business_city", businessCity);
      apiData.append("business_state", businessState);
      apiData.append("business_pincode", businessPincode);

      try {
        toast.dismiss();
        const apiRes = await postApiFormDataTokenWithProgress(`admin-update-business-details`, apiData, onProgressKycSubmit);

        // console.log(apiRes);
        if (apiRes.error) {
          toast.error(apiRes.message, {
            position: "bottom-center",
            style: {
              borderRadius: "10px",
              background: "#333",
              color: "#fff",
            },
          });
          setProgressKycSubmit(0);
        } else {
          toast.success(apiRes.message, {
            position: "bottom-center",
            style: {
              borderRadius: "10px",
              background: "#333",
              color: "#fff",
            },
          });

          route.push("/admin/profile");
        }
      } catch (error) {
        console.error("Error uploading image:", error);
      } finally {
        setFinalSubmitLoading(false);
      }

    }


  };


  const handleResend = () => {
    handleVerify();
  };

  const fetchCityData = async (id) => {
    try {

      const getState = await getWithToken("web/getCityData?stateId=" + id);
      // console.log(apiResData);
      if (getState.error === false) {
        setCityData(getState.result);

      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };

  const selectStateName = (value) => {

    setState(value[0]?.label);
    fetchCityData(value[0]?.value);

  };

  const selectCityName = (value) => {

    setCity(value[0]?.label);

  };


  const fetchCityBusinessData = async (id) => {
    try {

      const getState = await getWithToken("web/getCityData?stateId=" + id);
      // console.log(apiResData);
      if (getState.error === false) {
        setCityBusinessData(getState.result);

      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };

  const selectStateBusinessName = (value) => {

    setBusinessState(value[0]?.label);
    if(value[0]?.label){
      fetchCityBusinessData(value[0]?.value);
    }

  };

  const selectCityBusinessName = (value) => {

    setBusinessCity(value[0]?.label);

  };

  return (
    <div className="mt-4">


      <React.Fragment>
        <form>
          <div className="grid grid-cols-12 gap-4">

            <>
              <div className="col-span-12 mt-6 mb-4">
                <h4 className="text-sm font-medium text-default-600">
                  {lang("Enter_Your_Business_Details")}
                </h4>
              </div>

              <div className="col-span-12 lg:col-span-6">
                <Label htmlFor="Business Name">
                  {lang("Business_Name")}
                  <span style={{ color: "red" }}>*</span>
                </Label>
                <Input
                  value={businessName}
                  // onChange={(e) => setBusinessName(e.target.value)}
                  type="text"
                  placeholder={lang("Business_Name")}
                  onChange={(e) => {
                    const value = e.target.value;
                    const regex = /^[a-zA-Z_ ]*$/; // Only letters, numbers, and underscores allowed
                    if (regex.test(value)) {
                      setBusinessName(value); // Update state only if the value is valid
                    }
                  }}
                />
                {errors.businessName && (
                  <span
                    style={{
                      color: "tomato",
                      fontWeight: " ",
                      marginBottom: "10px",
                    }}
                    className="error-message"
                  >
                    {errors.businessName}
                  </span>
                )}
              </div>

              <div className="col-span-12 lg:col-span-6">
                <Label htmlFor="Enter Business Mobile">
                  {lang("Business_Mobile")}
                  <span style={{ color: "red" }}>*</span>
                </Label>
                <Input
                  value={businessMobile}
                  // onChange={(e) => setBusinessMobile(e.target.value)}
                  onChange={handleChangeBusinessMobile}
                  type="tel"
                  maxLength={10}
                  minLength={10}
                  placeholder={lang("Business_Mobile")}
                />
                {errors.businessMobile && (
                  <span
                    style={{
                      color: "tomato",
                      fontWeight: " ",
                      marginBottom: "10px",
                    }}
                    className="error-message"
                  >
                    {errors.businessMobile}
                  </span>
                )}
              </div>

              <div className="col-span-12 lg:col-span-6">
                <Label htmlFor="Enter Business Address">
                  {lang("Business_Address")}
                  <span style={{ color: "red" }}>*</span>
                </Label>
                <Input
                  value={businessAdd}
                  onChange={(e) => setBusinessAdd(e.target.value)}
                  type="text"
                  placeholder={lang("Business_Address")}
                />
                {errors.businessAdd && (
                  <span
                    style={{
                      color: "tomato",
                      fontWeight: " ",
                      marginBottom: "10px",
                    }}
                    className="error-message"
                  >
                    {errors.businessAdd}
                  </span>
                )}
              </div>
              <div className="col-span-12 lg:col-span-6">
                <Label htmlFor="Enter State">
                  {lang("State")}
                  <span style={{ color: "red" }}>*</span>
                </Label>
                {
                  stateData && stateData.length > 0 ?

                    <Select
                      options={stateData}
                      onChange={(values) => selectStateBusinessName(values)}
                      values={defaultValuesBState}
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                    />

                    :

                    <Select
                      onChange={(values) => selectStateBusinessName(values)}
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                    />
                }

                {errors.businessState && (
                  <span
                    style={{
                      color: "tomato",
                      fontWeight: " ",
                      marginBottom: "10px",
                    }}
                    className="error-message"
                  >
                    {errors.businessState}
                  </span>
                )}
              </div>
              <div className="col-span-12 lg:col-span-6">
                <Label htmlFor="Enter City">
                  {lang("City")}
                  <span style={{ color: "red" }}>*</span>
                </Label>
                {
                  cityBusinessData && cityBusinessData.length > 0 ?

                    <Select
                      options={cityBusinessData}
                      onChange={(values) => selectCityBusinessName(values)}
                      values={defaultValuesBCity}
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                    />

                    :

                    <Select
                      onChange={(values) => selectCityBusinessName(values)}
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                    />
                }

                {errors.businessCity && (
                  <span
                    style={{
                      color: "tomato",
                      fontWeight: " ",
                      marginBottom: "10px",
                    }}
                    className="error-message"
                  >
                    {errors.businessCity}
                  </span>
                )}
              </div>

              <div className="col-span-12 lg:col-span-6">
                <Label htmlFor="Pin Code">
                  {lang("Pin_Code")}
                  <span style={{ color: "red" }}>*</span>
                </Label>
                <Input
                  value={businessPincode}
                  onChange={handleChangeBusinessPincode}

                  type="text"
                  placeholder={lang("Pin_Code")}
                  maxLength={6}
                  minLength={6}
                />
                {errors.businessPincode && (
                  <span
                    style={{
                      color: "tomato",
                      fontWeight: " ",
                      marginBottom: "10px",
                    }}
                    className="error-message"
                  >
                    {errors.businessPincode}
                  </span>
                )}
              </div>

              <div className="col-span-12 lg:col-span-6">
                <Label htmlFor="Do you have GST Number">
                  {lang("Do_you_have_GST_Number")}
                  <span style={{ color: "red" }}>*</span>
                </Label>
                <select
                  onChange={handleSelectChange}
                  className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                >
                  <option value="">{lang("Do_you_have_GST_Number")}</option>
                  <option value="Yes" selected={gst == "Yes" ? true : false}>{lang("Yes")}</option>
                  <option value="No" selected={gst == "No" ? true : false}>{lang("No")}</option>
                </select>

                {showGSTInput && (
                  <div style={{ marginTop: "1rem" }}>
                    <Label
                      htmlFor="gstNumberInput"
                      style={{ display: "block", marginBottom: "0.5rem" }}
                    >
                      {lang("GST_Number")}:
                    </Label>
                    <Input
                      id="gstNumberInput"
                      type="text"
                      value={gstNumber.toUpperCase()}
                      onChange={(e) => setGSTNumber(e.target.value.split(" ").join(""))}
                      placeholder={lang("GST_Number")}
                      style={{
                        width: "100%",
                        padding: "0.5rem",
                        fontSize: "1rem",
                        border: "1px solid #ccc",
                        borderRadius: "5px",
                      }}
                    />
                    {errors.gstNumber && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.gstNumber}
                      </span>
                    )}
                  </div>
                )}
              </div>
            </>

          </div>
        </form>

        <div className="flex pt-2 ">

          <div className="flex-1	gap-4 " />
          <div className="flex	gap-2 ">

            <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

              <Button
                size="xs"
                variant="outline"
                color="success"
                type="button"
                className="cursor-pointer mt-5"
                onClick={() => {
                  handleKycSubmit();
                  // handleNext();
                }}
                disabled={finalSubmitLoading}
              >
                {lang("Submit")}
                {finalSubmitLoading ? (
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="2em"
                    height="2em"
                    viewBox="0 0 24 24"
                  >
                    <g
                      fill="none"
                      stroke="currentColor"
                      stroke-linecap="round"
                      stroke-width="2"
                    >
                      <path
                        stroke-dasharray="60"
                        stroke-dashoffset="60"
                        stroke-opacity="0.3"
                        d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                      >
                        <animate
                          fill="freeze"
                          attributeName="stroke-dashoffset"
                          dur="1.3s"
                          values="60;0"
                        />
                      </path>
                      <path
                        stroke-dasharray="15"
                        stroke-dashoffset="15"
                        d="M12 3C16.9706 3 21 7.02944 21 12"
                      >
                        <animate
                          fill="freeze"
                          attributeName="stroke-dashoffset"
                          dur="0.3s"
                          values="15;0"
                        />
                        <animateTransform
                          attributeName="transform"
                          dur="1.5s"
                          repeatCount="indefinite"
                          type="rotate"
                          values="0 12 12;360 12 12"
                        />
                      </path>
                    </g>
                  </svg>
                ) : null}
              </Button>

            </div>

          </div>
        </div>
      </React.Fragment>

    </div>
  );
};

export default BasicWizard;
